Clazz.declarePackage("J.api");
Clazz.declareInterface(J.api, "JmolScriptEvaluator");
;//5.0.1-v2 Mon Feb 26 04:48:36 CST 2024
